@@ -7,7 +7,7 @@ DRAWING_CHARS = ['#', '#', '#', '#', '#', '#', '#', ' ', ' ', ' ', ' ']
 
 def resize_image(image,new_width=40):
     width,height = image.size
-    ratio = height//width
+    ratio = height/width
     new_height = int(new_width*ratio*0.80)
     resized_image = image.resize((new_width,new_height))
     return(resized_image)
@@ -18,7 +18,7 @@ def pixels_to_ascii(image):
     return(characters)
     
 
-def main(new_width=40):
+def main_image(new_width=40):
     path =  inspect.getfile(requests)[:-20]+"m1key/profile.jpeg"
     image = Image.open(path)
     new_image = pixels_to_ascii((resize_image(image)).convert("L"))
@@ -27,4 +27,9 @@ def main(new_width=40):
     print(ascii_image)
     print()
     print("""Hello, it's Mithilesh Tiwari , aka m1key. Welcome to m1key world.
-Run m1key -h to know what you can do...""")
\ No newline at end of file
+Run m1key -h to know what you can do...""")
+
+def main():
+    path =  inspect.getfile(requests)[:-20]+"m1key/profile.txt"
+    f = open(path,"r")
+    print(f.read())
\ No newline at end of file
